kedro.framework.cli.cli — Kedro 0.17.6 documentation

# kedro.framework.cli.cli

Description

kedro is a CLI for managing Kedro projects.

This module implements commands available from the kedro CLI.

Functions

`get_project_context`([key, project_path]) | Gets the context value from context associated with the key.
`main`() | Main entry point.

Classes

`KedroCLI`(project_path) | A CommandCollection class to encapsulate the KedroCLI command loading.